@@ -5,6 +5,7 @@ use chrono::{DateTime, Local};
 
 use super::{csv, interaction};
 use super::currency::Currency;
+use super::files;
 
 pub struct Portfolio {
     categories: Vec<String>,
@@ -50,64 +51,69 @@ impl<'a> Portfolio {
     }
 }
 
-pub fn get_portfolio_interactively(file_name: Option<PathBuf>) -> Result<Option<Portfolio>, String> {
-    match file_name {
-        Some(name) => Ok(Some(csv::read_portfolio(&name)?)),
-        None => {
-            let name = select_portfolio_file();
-            if let Some(name) = name {
-                let p = Some(csv::read_portfolio(&name)?);
-                Ok(p)
-            } else {
-                Ok(None)
-            }
-        },
+pub fn get_portfolio_contents(portfolio_name: String) -> Result<String, String> { 
+    let portfolio_path = files::list_data_files().into_iter()
+        .find(|f| files::as_file_stem(f).eq(&portfolio_name));
+
+    if let Some(path) = portfolio_path {
+        std::fs::read_to_string(path).map_err(|e| format!("Failed to read portfolio file: {}", e))
+    } else {
+        Err(format!("Portfolio {} wasn't found. Make sure you've spelled it correctly", portfolio_name))
     }
 }
 
-pub fn get_or_create_portfolio_interactively(file_name: Option<PathBuf>) -> Result<(Option<Portfolio>, PathBuf), String> {
+pub fn get_portfolio_contents_interactively() -> Result<String, String> {
+    let portfolio_path = select_portfolio_file();
+
+    if let Some(path) = portfolio_path {
+        std::fs::read_to_string(path).map_err(|e| format!("Failed to read portfolio file: {}", e))
+    } else {
+        Err(String::from("Didn't find any portfolios"))
+    }
+}
+
+pub fn get_portfolio_interactively(file_name: Option<PathBuf>) -> Result<(Portfolio, PathBuf), String> {
     match file_name {
-        Some(name) => 
-            if name.exists() {
-                Ok((Some(csv::read_portfolio(&name)?), name))
-            } else {
-                Ok((None, name))
+        Some(name) => {
+            if !name.exists() {
+                return Err(format!("Portfolio {name} doesn't exist. Try running 'rustfolio new {name}' to create one", 
+                                        name = name.file_stem().map(|s| s.to_string_lossy().to_string()).unwrap_or(String::new())))
             }
-        ,
+            Ok((csv::read_portfolio(&name)?, name))
+        },
         None => {
             let name = select_portfolio_file();
             if let Some(name) = name {
-                let p = Some(csv::read_portfolio(&name)?);
+                let p = csv::read_portfolio(&name)?;
                 Ok((p, name))
             } else {
-                Ok((None, ask_for_new_file()?))
+                Err(String::from("No portfolios exist so far. Try running 'rustfolio new' to create one"))
             }
         },
     }
 }
 
-fn select_portfolio_file() -> Option<PathBuf> {
-    let mut files = super::files::list_data_files();
-    files.retain(|f| f.file_name().is_some());
-    if files.is_empty() {
-        return None;
+pub fn create_portfolio_interactively(file_name: PathBuf) -> Result<Portfolio, String> {
+    if file_name.exists() {
+        Err(String::from("Portfolio with provided file_name already exists"))
+    } else {
+        let mut portfolio = Portfolio::new();
+        interaction::populate_new_portfolio(&mut portfolio);
+        csv::save_portfolio(&file_name, &portfolio).map_err(|e| format!("Failed to save portfolio: {}", e))?;
+        Ok(portfolio)
     }
-
-    if files.len() == 1 {
-        return Some(files.remove(0));
-    }
-
-    Some(interaction::select_one("Select portfolio", files.into_iter(), |f| f.file_stem().map_or(String::new(), |stem| stem.to_string_lossy().to_string())))
 }
 
-fn ask_for_new_file() -> Result<PathBuf, String> {
-
+pub fn get_portfolio_name_interactively(portfolio_name: Option<String>) -> Result<PathBuf, String> {
     fn validation(s: &String) -> Result<String, String> {
         Ok(String::from(s))
     }
 
-    let input = interaction::Input::new("Your portfolio name", validation);
-    let portfolio_name = input.ask_for_input().unwrap_or(String::new());
+    let portfolio_name = portfolio_name.unwrap_or_else(|| {
+        let input = interaction::Input::new("Your portfolio name", validation);
+        input.ask_for_input().unwrap_or(String::new())
+    });
+
     let temp_path = std::path::PathBuf::from(portfolio_name.trim());
     match temp_path.file_stem() {
         Some(stem) => {
@@ -118,3 +124,16 @@ fn ask_for_new_file() -> Result<PathBuf, String> {
         None => Err(String::from("Invalid portfolio name")),
     }
 }
+
+fn select_portfolio_file() -> Option<PathBuf> {
+    let mut files = super::files::list_data_files();
+    if files.is_empty() {
+        return None;
+    }
+
+    if files.len() == 1 {
+        return Some(files.remove(0));
+    }
+
+    Some(interaction::select_one("Select portfolio", files.into_iter(), |f| super::files::as_file_stem(f)))
+}
